@@ -6,7 +6,7 @@ from sqlalchemy import bindparam
 
 import ormar  # noqa I100
 from ormar import MultipleMatches, NoMatch
-from ormar.exceptions import QueryDefinitionError
+from ormar.exceptions import ModelPersistenceError, QueryDefinitionError
 from ormar.queryset import FilterQuery
 from ormar.queryset.clause import QueryClause
 from ormar.queryset.prefetch_query import PrefetchQuery
@@ -395,6 +395,9 @@ class QuerySet:
         expr = expr.values(**new_kwargs)
 
         instance = self.model(**kwargs)
+        await self.model.Meta.signals.pre_save.send(
+            sender=self.model, instance=instance
+        )
         pk = await self.database.execute(expr)
 
         pk_name = self.model.get_column_alias(self.model_meta.pkname)
@@ -411,6 +414,9 @@ class QuerySet:
         ):
             instance = await instance.load()
         instance.set_save_status(True)
+        await self.model.Meta.signals.post_save.send(
+            sender=self.model, instance=instance
+        )
         return instance
 
     async def bulk_create(self, objects: List["Model"]) -> None:
@@ -446,7 +452,7 @@ class QuerySet:
         for objt in objects:
             new_kwargs = objt.dict()
             if pk_name not in new_kwargs or new_kwargs.get(pk_name) is None:
-                raise QueryDefinitionError(
+                raise ModelPersistenceError(
                     "You cannot update unsaved objects. "
                     f"{self.model.__name__} has to have {pk_name} filled."
                 )
